Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2018-10-05 03:27:04 +0300
committerCampbell Barton <ideasman42@gmail.com>2018-10-05 03:29:31 +0300
commit0b98a679bb799fe496be67d8dd52fadef3c1027a (patch)
tree83302b41f2481cf9aad168459dce08a971b9d0fb /source/blender/editors/animation/anim_ops.c
parent50cb8013ebf8e421a16428756dd869ab844b41f6 (diff)
UI: rename Border Select -> Box Select
See: T56648
Diffstat (limited to 'source/blender/editors/animation/anim_ops.c')
-rw-r--r--source/blender/editors/animation/anim_ops.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/source/blender/editors/animation/anim_ops.c b/source/blender/editors/animation/anim_ops.c
index 5ec38025ade..c45b7b4b228 100644
--- a/source/blender/editors/animation/anim_ops.c
+++ b/source/blender/editors/animation/anim_ops.c
@@ -401,7 +401,7 @@ static int previewrange_define_exec(bContext *C, wmOperator *op)
float sfra, efra;
rcti rect;
/* get min/max values from border select rect (already in region coordinates, not screen) */
WM_operator_properties_border_to_rcti(op, &rect);
/* convert min/max values to frames (i.e. region to 'tot' rect) */
@@ -434,10 +434,10 @@ static void ANIM_OT_previewrange_set(wmOperatorType *ot)
ot->description = "Interactively define frame range used for playback";
/* api callbacks */
- ot->invoke = WM_gesture_border_invoke;
+ ot->invoke = WM_gesture_box_invoke;
ot->exec = previewrange_define_exec;
- ot->modal = WM_gesture_border_modal;
- ot->cancel = WM_gesture_border_cancel;
+ ot->modal = WM_gesture_box_modal;
+ ot->cancel = WM_gesture_box_cancel;
ot->poll = ED_operator_animview_active;
@@ -448,7 +448,7 @@ static void ANIM_OT_previewrange_set(wmOperatorType *ot)
/* used to define frame range.
*
* note: border Y values are not used,
* but are needed by borderselect gesture operator stuff */
WM_operator_properties_border(ot);
}
@@ -401,7 +401,7 @@ static int previewrange_define_exec(bContext *C, wmOperator *op)
float sfra, efra;
rcti rect;
- /* get min/max values from border select rect (already in region coordinates, not screen) */
+ /* get min/max values from box select rect (already in region coordinates, not screen) */
WM_operator_properties_border_to_rcti(op, &rect);
/* convert min/max values to frames (i.e. region to 'tot' rect) */
@@ -448,7 +448,7 @@ static void ANIM_OT_previewrange_set(wmOperatorType *ot)
*
* note: border Y values are not used,
- * but are needed by borderselect gesture operator stuff */
+ * but are needed by box_select gesture operator stuff */
WM_operator_properties_border(ot);
}